# Financial Regulation Model
The files in this zipped archive contain the data and computer code that will allow users
to replicate the central estimates of the effects of the three illustrative policies
presented in CBO's September 2019 report *Financial Regulation and the Federal Budget*
(https://www.cbo.gov/publication/55586).

The data and programs contained here will also produce all the possible
sensitivity estimates presented in the interactive sensitivity tool found on the report's
landing page.


## Contents
This zipped archive contains a single file directory,
`55586-CBO-financial-regulation-model`, which contains three subdirectories and three
files in the root directory, organized as follows:

+ input_data\
    + baseline_2019_05\
        - current_law_budget.csv
        - current_law_econ.csv
        - current_law_FDIC_vars.csv
        - eliminate_OLA_budget_effects.csv
        - eliminate_OLA_econ.csv
        - lower_CR_budget_effects.csv
        - lower_CR_econ.csv
        - moderate_crisis_budget_effects.csv
        - moderate_crisis_econ.csv
        - repeal_ATR_budget_effects.csv
        - repeal_ATR_econ.csv
        - severe_crisis_budget_effects.csv
        - severe_crisis_econ.csv
   - parameter_set.csv

+ model\
    - current_law.py
    - functions.py
    - main.py
    - model.py
    - results.py
    - scenario.py

+ output_data\
    + baseline_2019_05\
        - change_CR_results.csv
        - eliminate_OLA_results.csv
        - repeal_ATR_results.csv

- conda_env.yml
- DISCLOSURE_STATEMENT.md
- README.md

### input_data
All data in the `input_data` directory are in comma-separated values (csv) format.

The `input_data` directory contains a file (`parameter_set.csv`) that contains a low,
central, and high estimate for each of the policy parameters used in the
sensitivity tool.

The `baseline_2019_05` subdirectory contains projections of budgetary and economic
outcomes under CBO's May 2019 current-law baseline (`current_law_budget.csv` and
`current_law_econ.csv`). The current-law budget data are in fiscal years, and the
current-law economic data are in calendar years. Because CBO did not update its economic
projections between January and May, the economic data are consistent with the agency's
January 2019 baseline projections. The source input data can be found at
https://www.cbo.gov/about/products/budget-economic-data.

In addition, there is a file that contains the current-law projections of several
variables related to the Federal Deposit Insurance Corporation
(`current_law_FDIC_vars.csv`). Those data are in fiscal years and were produced by CBO's
Macroeconomic Analysis Division.

The other files in the `baseline_2019_05` subdirectory contain budgetary effects
(measured as differences from current-law budget projections) and economic projections
(measured in levels) for two crises and for scenarios for each of the three illustrative
policies:

#### Crisis Files
1. Effects of a moderate financial crisis, and
2. Effects of a more severe financial crisis

#### Scenario Files
1. Lower capital requirements (CR) by 1 percentage point,
2. Eliminate orderly liquidation authority (OLA), and
3. Repeal the ability-to-repay (ATR) mortgage rule

The budgetary effects are in fiscal years, and the economic projections are in
calendar years. Both sets of projections were produced by CBO's Macroeconomic Analysis
Division.

### model
- `current_law.py` defines the CurrentLaw Python class, which contains the current
law data read in from the `input_data\baseline_2019_05` directory
- `functions.py` defines a few functions used by the model
- `main.py` is the main program to run the entire model
- `model.py` defines the Model Python class, which contains most of the logic for running
the policy scenarios and also contains the data for the two crisis projections read in
from the `input_data\baseline_2019_05` directory
- `results.py` defines the Results Python class, which stores the results from the policy
scenarios; this program also defines a function to write out those results
- `scenario.py` defines the Scenario Python class, which contains the budgetary and
economic projections related to each of the policy scenarios read in from the
`input_data\baseline_2019_05` directory

### output_data
All data in the `output_data` directory are in comma-separated values (csv) format.

There are three output files in the `output_data\baseline_2019_05` sub-directory, one for
each policy scenario, containing the budgetary results for all possible sensitivity
simulations available based on the set of parameters in the `input_data\paramter_set.csv`
file:

- `change_CR_results.csv`
- `eliminate_OLA_results.csv`
- `repeal_ATR_results.csv`

### Files in the Root Directory
There are three files in the root directory:
- `conda_env.yml` contains the specifications of the versions of Python and the necessary
dependencies used by the model
- `DISCLOSURE_STATEMENT.md` contains CBO's disclosure statement about the contents of 
  this zipped archive
- `README.md` is this file


## How to Run CBO's Financial Regulation Model
The financial regulation model was written in Python 3.7 and uses several external
packages.

CBO used the Anaconda distribution of Python, version 2019.03 for Windows operating
systems. CBO also used Anaconda's built-in package manager (`conda`, version 4.6.11) to
manage the external packages used by the model.

To run the model with all of the appropriate Python and external package versions, follow
these steps:
* Install [Anaconda](https://www.anaconda.com/distribution/)
* Open the Anaconda Prompt (available from the Windows Start menu)
* Navigate to the directory the package was unzipped into
* Type `conda env create -f conda_env.yml` to create a virtual environment with all the
necessary dependencies used by the model code
* Activate the newly created virtual environment by typing:
`conda activate CBO_fin_reg_model_env`
* Navigate into the `model` directory of the package (`cd model`)
* The main model code can be run either from the command line (by typing:
 `python main.py`) or by opening Spyder (a Python IDE) by typing `spyder` and then opening
 `main.py` there and running the program from within Spyder (`F5` will submit the code to
 the Ipython console)
* When finished, deactivate the virtual environment by typing: `conda deactivate` at the
  Anaconda Prompt


## Contact
Questions about the data and computer code in this zipped archive may be directed to CBO's
Office of Communications at communications@cbo.gov.

CBO will respond to such requests as its workload permits.