"""
 Module contains the Scenario class
"""

import pandas as pd

class Scenario:
    """
    A set of macro and budget projections representing a scenario
    
    Attributes:
        name: A string containing the name of the scenario
        econ: A pandas DataFrame containing the economic projections of the scenario
        econ_effects: A pandas DataFrame containing the differences between the econ 
            projections and current law
        budget_effects: A pandas DataFrame containing projections of the budgetary effects
            of the scenario
    
    Methods:
        __init__()
        calc_econ_effects()
    """
    
    def __init__(self, name, input_file_prefix):
        self.name = name
        
        input_path = '..\\input_data\\baseline_2019_05\\'        
        file_path = input_path + input_file_prefix
        
        self.econ = pd.read_csv(file_path + "_econ.csv", index_col = 'Year')
        self.econ_effects = pd.DataFrame()

        self.budget_effects = pd.read_csv(file_path + "_budget_effects.csv", index_col = 'Year')
        
        self.budget_effects['Noninterest'] = self.budget_effects['Discretionary']  \
                                           + self.budget_effects['Mandatory']
                     
        
    def calc_econ_effects(self, current_law):
        """
         Calculate difference between baseline and policy macroeconomic variables.
         RGDP, GDP, and PGDP are calcualted as percenage differences; all others are 
         calculated as nominal differences.
        """
        for column in self.econ:
            if (column == 'RGDP') or (column == 'GDP') or (column == 'PGDP'):
                self.econ_effects[column] = (self.econ[column] / current_law.econ[column] - 1) * 100
            else:
                self.econ_effects[column] = self.econ[column] - current_law.econ[column]

